#
# spec file for package python-dunamai
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dunamai
Version:        1.21.0
Release:        1.1
Summary:        Dynamic version generation
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/mtkennerly/dunamai
Source0:        https://files.pythonhosted.org/packages/source/d/dunamai/dunamai-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
## needed for tests
BuildRequires:  %{python_module pytest}
BuildRequires:  git
%python_subpackages

%description
Dunamai is a Python 3.5+ library and command line tool for producing dynamic,
standards-compliant version strings, derived from tags in your version
control system. This facilitates uniquely identifying nightly or per-commit
builds in continuous integration and releasing new versions of your software
simply by creating a tag.

%prep
%autosetup -p1 -n dunamai-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/dunamai
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative dunamai

%post
%python_install_alternative dunamai

%postun
%python_uninstall_alternative dunamai

%check
donttest="git"
%pytest -k "not $donttest"

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/dunamai
%{python_sitelib}/dunamai
%{python_sitelib}/dunamai-%{version}.dist-info

%changelog
* Fri May  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.21.0:
  * Generally, when Dunamai can detect the VCS in use, but
    there's no version set yet, then Dunamai uses 0.0.0 as a
    fallback, unless strict mode is enabled.
    However, if there were some tags and none matched the version
    pattern, then Dunamai would yield an error.
  * Added `--ignore-untracked` option to control checking whether
    the repository is dirty.
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.20.0:
  * Updated `Version.bump()` to add a `smart` argument,
    which only bumps when `distance != 0`.
* Sat Feb 17 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.19.2
  * ixed an exception when a Git repository had a broken ref
- update to 1.19.1:
  * Relaxed Python bounds
  * Fixed some git log commands that did not include -c log.showsignature=false
* Sat Dec 16 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging of version 1.19
